@@ -28,6 +28,10 @@ jenkinsURL="https://codeready-workspaces-jenkins.rhev-ci-vms.eng.rdu2.redhat.com
 theTarGzs="
 lastSuccessfulBuild/artifact/codeready-workspaces-deprecated/php/target/codeready-workspaces-stacks-language-servers-dependencies-php-x86_64.tar.gz
 lastSuccessfulBuild/artifact/codeready-workspaces-deprecated/php/target/codeready-workspaces-stacks-language-servers-dependencies-php-xdebug-x86_64.tar.gz
+lastSuccessfulBuild/artifact/codeready-workspaces-deprecated/php/target/codeready-workspaces-stacks-language-servers-dependencies-php-s390x.tar.gz
+lastSuccessfulBuild/artifact/codeready-workspaces-deprecated/php/target/codeready-workspaces-stacks-language-servers-dependencies-php-xdebug-s390x.tar.gz
+lastSuccessfulBuild/artifact/codeready-workspaces-deprecated/php/target/codeready-workspaces-stacks-language-servers-dependencies-php-ppc64le.tar.gz
+lastSuccessfulBuild/artifact/codeready-workspaces-deprecated/php/target/codeready-workspaces-stacks-language-servers-dependencies-php-xdebug-ppc64le.tar.gz
 "
 lastSuccessfulURL="${jenkinsURL}/lastSuccessfulBuild/api/xml?xpath=//" # id or description
 
@@ -131,11 +135,6 @@ function getFingerprints ()
 # get the public URL for the tarball(s)
 outputFiles=""
 
-
-#### fetch MANUALLY ADDED ARTIFACTS FROM kcrane - these are build by hand and therefore are not allowed in a GA
-log "[WARN] p and z sources not updated.  Manually built until have VM"
-rhpkg sources
-
 #### override any existing tarballs with newer ones from Jenkins build
 for theTarGz in ${theTarGzs}; do
 	outputFile=${theTarGz##*/}
@@ -148,10 +147,6 @@ for theTarGz in ${theTarGzs}; do
 	fi
 done
 
-#### ensure that MANUALLY ADDED ARTIFACTS FROM kcrane persist into sources file
-outputFiles="${outputFiles} codeready-workspaces-stacks-language-servers-dependencies-php-s390x.tar.gz"
-outputFiles="${outputFiles} codeready-workspaces-stacks-language-servers-dependencies-php-xdebug-s390x.tar.gz"
-
 if [[ ${outputFiles} ]]; then
 	log "[INFO] Upload new sources:${outputFiles}"
 	rhpkg new-sources ${outputFiles}
