@@ -6,7 +6,7 @@
  * Event class represents and event firing on a file descriptor being ready to read from or write to; a file descriptor becoming ready to read from or write to(edge-triggered I/O only); a timeout expiring; a signal occurring; a user-triggered event.
  * Every event is associated with EventBase . However, event will never fire until it is added (via Event::add() ). An added event remains in pending state until the registered event occurs, thus turning it to active state. To handle events user may register a callback which is called when event becomes active. If event is configured persistent , it remains pending. If it is not persistent, it stops being pending when it's callback runs. Event::del() method deletes event, thus making it non-pending. By means of Event::add() method it could be added again.
  *
- * @property bool $pending
+ * @property-read  bool $pending
  *
  * @author Kazuaki MABUCHI
  * @copyright Сopyright (https://php.net/manual/cc.license.php) by the PHP Documentation Group is licensed under [CC by 3.0 or later](https://creativecommons.org/licenses/by/3.0/).
@@ -22,8 +22,6 @@ final class Event
     const SIGNAL = 8;
     const TIMEOUT = 1;
 
-    public $pending;
-
     /**
      * __construct.
      * Constructs Event object.
@@ -36,7 +34,7 @@ final class Event
      *
      * @see https://php.net/manual/en/event.construct.php
      */
-    public function __construct(EventBase $base, mixed $fd, int $what, callable $cb, mixed $arg = null)
+    public function __construct(EventBase $base, $fd, int $what, callable $cb, $arg = null)
     {
     }
 
@@ -50,7 +48,7 @@ final class Event
      *
      * @see https://php.net/manual/en/event.add.php
      */
-    public function add(double $timeout = -1): bool
+    public function add(float $timeout = -1): bool
     {
     }
 
@@ -64,7 +62,7 @@ final class Event
      *
      * @see https://php.net/manual/en/event.addsignal.php
      */
-    public function addSignal(double $timeout = -1): bool
+    public function addSignal(float $timeout = -1): bool
     {
     }
 
@@ -78,7 +76,7 @@ final class Event
      *
      * @see https://php.net/manual/en/event.addtimer.php
      */
-    public function addTimer(double $timeout = -1): bool
+    public function addTimer(float $timeout = -1): bool
     {
     }
 
@@ -168,7 +166,7 @@ final class Event
      *
      * @see https://php.net/manual/en/event.set.php
      */
-    public function set(EventBase $base, mixed $fd, int $what, callable $cb, mixed $arg): bool
+    public function set(EventBase $base, $fd, int $what, callable $cb, $arg): bool
     {
     }
 
@@ -196,7 +194,7 @@ final class Event
      *
      * @see https://php.net/manual/en/event.settimer.php
      */
-    public function setTimer(EventBase $base, callable $cb, mixed $arg): bool
+    public function setTimer(EventBase $base, callable $cb, $arg): bool
     {
     }
 
@@ -213,7 +211,7 @@ final class Event
      *
      * @see https://php.net/manual/en/event.signal.php
      */
-    public static function signal(EventBase $base, int $signum, callable $cb, mixed $arg): Event
+    public static function signal(EventBase $base, int $signum, callable $cb, $arg): Event
     {
     }
 
@@ -229,7 +227,7 @@ final class Event
      *
      * @see https://php.net/manual/en/event.timer.php
      */
-    public static function timer(EventBase $base, callable $cb, mixed $arg): Event
+    public static function timer(EventBase $base, callable $cb, $arg): Event
     {
     }
 }
@@ -287,7 +285,7 @@ final class EventBase
      *
      * @see https://php.net/manual/en/eventbase.exit.php
      */
-    public function exit(double $timeout): bool
+    public function exit(float $timeout): bool
     {
     }
 
@@ -333,7 +331,7 @@ final class EventBase
      *
      * @see https://php.net/manual/en/eventbase.gettimeofdaycached.php
      */
-    public function getTimeOfDayCached(): double
+    public function getTimeOfDayCached(): float
     {
     }
 
@@ -420,8 +418,8 @@ final class EventBase
  * EventBuffer represents Libevent's "evbuffer", an utility functionality for buffered I/O.
  * Event buffers are meant to be generally useful for doing the "buffer" part of buffered network I/O.
  *
- * @property int $length
- * @property int $contiguous_space
+ * @property-read  int $length
+ * @property-read  int $contiguous_space
  *
  * @author Kazuaki MABUCHI
  * @copyright Copyright (https://php.net/manual/cc.license.php) by the PHP Documentation Group is licensed under [CC by 3.0 or later](https://creativecommons.org/licenses/by/3.0/).
@@ -437,9 +435,6 @@ class EventBuffer
     const PTR_SET = 0;
     const PTR_ADD = 1;
 
-    public $length;
-    public $contiguous_space;
-
     /**
      * __construct.
      * Constructs EventBuffer object.
@@ -636,7 +631,7 @@ class EventBuffer
      *
      * @see https://php.net/manual/en/eventbuffer.readfrom.php
      */
-    public function readFrom(mixed $fd, int $howmuch): int
+    public function readFrom($fd, int $howmuch): int
     {
     }
 
@@ -666,7 +661,7 @@ class EventBuffer
      *
      * @see https://php.net/manual/en/eventbuffer.search.php
      */
-    public function search(string $what, int $start = 1, int $end = 1): mixed
+    public function search(string $what, int $start = 1, int $end = 1)
     {
     }
 
@@ -681,7 +676,7 @@ class EventBuffer
      *
      * @see https://php.net/manual/en/eventbuffer.searcheol.php
      */
-    public function searchEol(int $start = 1, int $eol_style = EOL_ANY): mixed
+    public function searchEol(int $start = 1, int $eol_style = EOL_ANY)
     {
     }
 
@@ -737,7 +732,7 @@ class EventBuffer
      *
      * @see https://php.net/manual/en/eventbuffer.write.php
      */
-    public function write(mixed $fd, int $howmuch): int
+    public function write($fd, int $howmuch): int
     {
     }
 }
@@ -755,8 +750,8 @@ class EventBuffer
  *
  * @property int $fd
  * @property int $priority
- * @property EventBuffer $input
- * @property EventBuffer $output
+ * @property-read  EventBuffer $input
+ * @property-read  EventBuffer $output
  *
  * @author Kazuaki MABUCHI
  * @copyright Copyright (https://php.net/manual/cc.license.php) by the PHP Documentation Group is licensed under [CC by 3.0 or later](https://creativecommons.org/licenses/by/3.0/).
@@ -779,11 +774,6 @@ final class EventBufferEvent
     const SSL_CONNECTING = 1;
     const SSL_ACCEPTING = 2;
 
-    public $fd;
-    public $priority;
-    public $input;
-    public $output;
-
     /**
      * __construct.
      * Constructs EventBufferEvent object.
@@ -797,7 +787,7 @@ final class EventBufferEvent
      *
      * @see https://php.net/manual/en/eventbufferevent.construct.php
      */
-    public function __construct(EventBase $base, mixed $socket = null, int $options = 0, callable $readcb = null, callable $writecb = null, callable $eventcb = null)
+    public function __construct(EventBase $base, $socket = null, int $options = 0, callable $readcb = null, callable $writecb = null, callable $eventcb = null)
     {
     }
 
@@ -1131,7 +1121,7 @@ final class EventBufferEvent
      *
      * @see https://secure.php.net/manual/en/eventbufferevent.sslsocket.php
      */
-    public static function sslSocket(EventBase $base, mixed $socket, EventSslContext $ctx, int $state, int $options): EventBufferEvent
+    public static function sslSocket(EventBase $base, $socket, EventSslContext $ctx, int $state, int $options): EventBufferEvent
     {
     }
 
@@ -1406,7 +1396,7 @@ final class EventHttp
      *
      * @see https://secure.php.net/manual/en/eventhttp.accept.php
      */
-    public function accept(mixed $socket): bool
+    public function accept($socket): bool
     {
     }
 
@@ -1605,7 +1595,7 @@ class EventHttpConnection
      *
      * @see https://secure.php.net/manual/en/eventhttpconnection.setclosecallback.php
      */
-    public function setCloseCallback(callable $callback, mixed $data): void
+    public function setCloseCallback(callable $callback, $data): void
     {
     }
 
@@ -1792,7 +1782,7 @@ class EventHttpRequest
  * EventListener.
  * Represents a connection listener.
  *
- * @property int $fd
+ * @property-read  int $fd
  *
  * @author Kazuaki MABUCHI
  * @copyright Copyright (https://secure.php.net/manual/cc.license.php) by the PHP Documentation Group is licensed under [CC by 3.0 or later](https://creativecommons.org/licenses/by/3.0/).
@@ -1807,8 +1797,6 @@ final class EventListener
     const OPT_REUSEABLE = 8;
     const OPT_THREADSAFE = 16;
 
-    public $fd;
-
     /**
      * __construct.
      * Creates new connection listener associated with an event base.
@@ -1822,7 +1810,7 @@ final class EventListener
      *
      * @see https://secure.php.net/manual/en/eventlistener.construct.php
      */
-    public function __construct(EventBase $base, callable $cb, mixed $data, int $flags, int $backlog, mixed $target)
+    public function __construct(EventBase $base, callable $cb, $data, int $flags, int $backlog, $target)
     {
     }
 
@@ -1871,7 +1859,7 @@ final class EventListener
      *
      * @see https://secure.php.net/manual/en/eventlistener.getsocketname.php
      */
-    public static function getSocketName(string &$address, mixed &$port): bool
+    public static function getSocketName(string &$address, &$port): bool
     {
     }
 
@@ -1884,7 +1872,7 @@ final class EventListener
      *
      * @see https://secure.php.net/manual/en/eventlistener.setcallback.php
      */
-    public function setCallback(callable $cb, mixed $arg = null): void
+    public function setCallback(callable $cb, $arg = null): void
     {
     }
 
@@ -1906,8 +1894,6 @@ final class EventListener
  * EventSslContext.
  * Represents SSL_CTX structure. Provides methods and properties to configure the SSL context.
  *
- * @property string $local_cert
- * @property string $local_pk
  *
  * @author Kazuaki MABUCHI
  * @copyright Copyright (https://secure.php.net/manual/cc.license.php) by the PHP Documentation Group is licensed under [CC by 3.0 or later](https://creativecommons.org/licenses/by/3.0/).
@@ -2006,7 +1992,7 @@ final class EventUtil
      *
      * @see https://secure.php.net/manual/en/eventutil.getlastsocketerrno.php
      */
-    public static function getLastSocketErrno(mixed $socket = null): int
+    public static function getLastSocketErrno($socket = null): int
     {
     }
 
@@ -2020,7 +2006,7 @@ final class EventUtil
      *
      * @see https://secure.php.net/manual/en/eventutil.getlastsocketerror.php
      */
-    public static function getLastSocketError(mixed $socket): string
+    public static function getLastSocketError($socket): string
     {
     }
 
@@ -2034,7 +2020,7 @@ final class EventUtil
      *
      * @see https://secure.php.net/manual/en/eventutil.getsocketfd.php
      */
-    public static function getSocketFd(mixed $socket): int
+    public static function getSocketFd($socket): int
     {
     }
 
@@ -2050,7 +2036,7 @@ final class EventUtil
      *
      * @see https://secure.php.net/manual/en/eventutil.getsocketname.php
      */
-    public static function getSocketName(mixed $socket, string &$address, mixed &$port): bool
+    public static function getSocketName($socket, string &$address, &$port): bool
     {
     }
 
@@ -2067,7 +2053,7 @@ final class EventUtil
      *
      * @see https://secure.php.net/manual/en/eventutil.setsocketoption.php
      */
-    public static function setSocketOption(mixed $socket, int $level, int $optname, mixed $optval): bool
+    public static function setSocketOption($socket, int $level, int $optname, $optval): bool
     {
     }
 
