@@ -10,7 +10,7 @@
  * @param string $oldpw [optional] The old password of this user. May be omitted depending of server configuration.
  * @param string $newpw [optional] The new password for this user. May be omitted or empty to have a generated password.
  * @param array $serverctrls [optional] If provided, a password policy request control is send with the request and this is filled with an array of LDAP Controls returned with the request.
- * @return mixed Returns the generated password if newpw is empty or omitted. Otherwise returns TRUE on success and FALSE on failure.
+ * @return string|bool Returns the generated password if newpw is empty or omitted. Otherwise returns TRUE on success and FALSE on failure.
  * @since 7.2
  */
 function ldap_exop_passwd ($link , $user = "" , $oldpw = "" , $newpw = "" , array &$serverctrls = []) {}
@@ -21,7 +21,7 @@ function ldap_exop_passwd ($link , $user = "" , $oldpw = "" , $newpw = "" , arra
  * @param resource $link An LDAP link identifier, returned by ldap_connect().
  * @param string $dn dn of the entry to refresh.
  * @param int $ttl $ttl Time in seconds (between 1 and 31557600) that the client requests that the entry exists in the directory before being automatically removed.
- * @return mixed From RFC: The responseTtl field is the time in seconds which the server chooses to have as the time-to-live field for that entry. It must not be any smaller than that which the client requested, and it may be larger. However, to allow servers to maintain a relatively accurate directory, and to prevent clients from abusing the dynamic extensions, servers are permitted to shorten a client-requested time-to-live value, down to a minimum of 86400 seconds (one day). FALSE will be returned on error.
+ * @return int|false From RFC: The responseTtl field is the time in seconds which the server chooses to have as the time-to-live field for that entry. It must not be any smaller than that which the client requested, and it may be larger. However, to allow servers to maintain a relatively accurate directory, and to prevent clients from abusing the dynamic extensions, servers are permitted to shorten a client-requested time-to-live value, down to a minimum of 86400 seconds (one day). FALSE will be returned on error.
  * @since 7.3
  */
 function ldap_exop_refresh ($link, $dn ,$ttl) {}
@@ -30,7 +30,7 @@ function ldap_exop_refresh ($link, $dn ,$ttl) {}
  * WHOAMI extended operation helper
  * @link https://www.php.net/manual/en/function.ldap-exop-whoami.php
  * @param resource $link An LDAP link identifier, returned by ldap_connect().
- * @return mixed The data returned by the server, or FALSE on error.
+ * @return string|false The data returned by the server, or FALSE on error.
  * @since 7.2
  */
 function ldap_exop_whoami ($link) {}
@@ -44,7 +44,7 @@ function ldap_exop_whoami ($link) {}
  * @param array $serverctrls [optional] If provided, a password policy request control is send with the request and this is filled with an array of LDAP Controls returned with the request.
  * @param string $retdata [optional] Will be filled with the extended operation response data if provided. If not provided you may use ldap_parse_exop on the result object later to get this data.
  * @param string $retoid [optional] Will be filled with the response OID if provided, usually equal to the request OID.
- * @return mixed When used with retdata, returns TRUE on success or FALSE on error. When used without retdata, returns a result identifier or FALSE on error.
+ * @return resource|bool When used with retdata, returns TRUE on success or FALSE on error. When used without retdata, returns a result identifier or FALSE on error.
  * @since 7.2
  */
 function ldap_exop ($link , $reqoid , $reqdata = null , $serverctrls = [], &$retdata, &$retoid) {}
@@ -131,7 +131,7 @@ function ldap_bind ($link_identifier, $bind_rdn = null, $bind_password = null) {
  * @param string $bind_rdn [optional]
  * @param string $bind_password [optional]
  * @param array $serverctrls [optional] Array of LDAP Controls to send with the request.
- * @return resource
+ * @return resource|false
  * @since 7.3
  */
 function ldap_bind_ext ($link_identifier, $bind_rdn = null, $bind_password = null, $serverctrls = []) {}
@@ -374,7 +374,7 @@ function ldap_count_entries ($link_identifier, $result_identifier) {}
  * An LDAP link identifier, returned by <b>ldap_connect</b>.
  * </p>
  * @param resource $result_identifier
- * @return resource the result entry identifier for the first entry on success and
+ * @return resource|false the result entry identifier for the first entry on success and
  * <b>FALSE</b> on error.
  */
 function ldap_first_entry ($link_identifier, $result_identifier) {}
@@ -427,10 +427,11 @@ function ldap_get_entries ($link_identifier, $result_identifier) {}
  * An LDAP link identifier, returned by <b>ldap_connect</b>.
  * </p>
  * @param resource $result_entry_identifier
+ * @param int $dummy_ber [optional] is the identifier to internal memory location pointer. This parameter is no longer used as this is now handled automatically by PHP. For backwards compatibility PHP will not throw an error if this parameter is passed.
  * @return string|false the first attribute in the entry on success and <b>FALSE</b> on
  * error.
  */
-function ldap_first_attribute ($link_identifier, $result_entry_identifier) {}
+function ldap_first_attribute ($link_identifier, $result_entry_identifier, $dummy_ber = null) {}
 
 /**
  * Get the next attribute in result
@@ -439,10 +440,11 @@ function ldap_first_attribute ($link_identifier, $result_entry_identifier) {}
  * An LDAP link identifier, returned by <b>ldap_connect</b>.
  * </p>
  * @param resource $result_entry_identifier
+ * @param int $dummy_ber [optional] The internal state of the pointer is maintained by this parameter. This parameter is no longer used as this is now handled automatically by PHP. For backwards compatibility PHP will not throw an error if this parameter is passed.
  * @return string|false the next attribute in an entry on success and <b>FALSE</b> on
  * error.
  */
-function ldap_next_attribute ($link_identifier, $result_entry_identifier) {}
+function ldap_next_attribute ($link_identifier, $result_entry_identifier, $dummy_ber) {}
 
 /**
  * Get attributes from a search result entry
@@ -581,7 +583,7 @@ function ldap_add ($link_identifier, $dn, array $entry, $serverctrls = []) {}
  * </code>
  * </p>
  * @param array $serverctrls [optional] Array of LDAP Controls to send with the request.
- * @return resource
+ * @return resource|false
  * @since 7.4
  */
 function ldap_add_ext ($link_identifier, $dn, array $entry, $serverctrls = []) {}
@@ -611,7 +613,7 @@ function ldap_delete ($link_identifier, $dn, $serverctrls = []) {}
  * The distinguished name of an LDAP entity.
  * </p>
  * @param array $serverctrls [optional] Array of LDAP Controls to send with the request.
- * @return resource
+ * @return resource|false
  * @since 7.3
  */
 function ldap_delete_ext ($link_identifier, $dn, $serverctrls = []) {}
@@ -660,7 +662,7 @@ function ldap_mod_add ($link_identifier, $dn, array $entry, $serverctrls = []) {
  * </p>
  * @param array $entry
  * @param array $serverctrls [optional] Array of LDAP Controls to send with the request.
- * @return resource
+ * @return resource|false
  */
 function ldap_mod_add_ext ($link_identifier, $dn, array $entry, $serverctrls = []) {}
 
@@ -691,7 +693,7 @@ function ldap_mod_replace ($link_identifier, $dn, array $entry, $serverctrls = [
  * </p>
  * @param array $entry
  * @param array $serverctrls [optional] Array of LDAP Controls to send with the request.
- * @return resource
+ * @return resource|false
  * @since 7.3
  */
 function ldap_mod_replace_ext ($link_identifier, $dn, array $entry, $serverctrls = []) {}
@@ -723,7 +725,7 @@ function ldap_mod_del ($link_identifier, $dn, array $entry, $serverctrls = []) {
  * </p>
  * @param array $entry
  * @param array $serverctrls [optional] Array of LDAP Controls to send with the request.
- * @return resource
+ * @return resource|false
  * @since 7.3
  */
 function ldap_mod_del_ext ($link_identifier, $dn, array $entry, $serverctrls = []) {}
@@ -794,6 +796,7 @@ function ldap_compare ($link_identifier, $dn, $attribute, $value, $serverctrls =
  * The attribute to use as a key in the sort.
  * </p>
  * @deprecated 7.0
+ * @removed 8.0
  * @return bool
  */
 function ldap_sort ($link, $result, $sortfilter) {}
@@ -843,7 +846,7 @@ function ldap_rename ($link_identifier, $dn, $newrdn, $newparent, $deleteoldrdn,
  * is retained as non-distinguished values of the entry.
  * </p>
  * @param array $serverctrls [optional] Array of LDAP Controls to send with the request.
- * @return resource
+ * @return resource|false
  * @since 7.3
  */
 function ldap_rename_ext ($link_identifier, $dn, $newrdn, $newparent, $deleteoldrdn, $serverctrls = []) {}
@@ -1100,7 +1103,7 @@ function ldap_set_rebind_proc ($link, callable $callback) {}
  * </p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  * @since 5.4
- * @deprecated Since 7.4
+ * @deprecated 7.4
  */
 function ldap_control_paged_result ($link, $pagesize, $iscritical = false, $cookie = "") {}
 
@@ -1119,7 +1122,7 @@ function ldap_control_paged_result ($link, $pagesize, $iscritical = false, $cook
  * </p>
  * @return bool <b>TRUE</b> on success or <b>FALSE</b> on failure.
  * @since 5.4
- * @deprecated Since 7.4
+ * @deprecated 7.4
  */
 function ldap_control_paged_result_response ($link, $result, &$cookie = null, &$estimated = null) {}
 
@@ -1215,6 +1218,14 @@ function ldap_escape ($value, $ignore = "", $flags = 0) {}
  */
 function ldap_modify_batch ( $link_identifier , $dn , $entry, $serverctrls = []) {}
 
+/**
+ * @param resource $link_identifier
+ * @param resource $result_identifier
+ * @return int returns the number of reference messages in a search result.
+ * @since 8.0
+ */
+function ldap_count_references($link_identifier, $result_identifier){}
+
 define('LDAP_ESCAPE_FILTER', 1);
 define ('LDAP_ESCAPE_DN', 2);
 define ('LDAP_DEREF_NEVER', 0);
