@@ -340,6 +340,15 @@ function readdir ($dir_handle = null) {}
  */
 function dir ($directory, $context = null) {}
 
+/**
+ * Alias of dir()
+ * @param resource $context
+ * @since 8.0
+ * @return Directory|false
+ * @see dir()
+ */
+function getdir(string $path, $context = null) {}
+
 /**
  * List files and directories inside the specified path
  * @link https://php.net/manual/en/function.scandir.php
@@ -544,10 +553,10 @@ function is_writable ($filename) {}
 function is_writeable ($filename) {}
 
 /**
- * Tells whether a file exists and is readable
+ * Tells whether a file or a directory exists and is readable
  * @link https://php.net/manual/en/function.is-readable.php
  * @param string $filename <p>
- * Path to the file.
+ * Path to the file or directory.
  * </p>
  * @return bool true if the file or directory specified by
  * filename exists and is readable, false otherwise.
@@ -962,6 +971,7 @@ function mail ($to, $subject, $message, $additional_headers = null, $additional_
  * </p>
  * @return int The hash value of addr.
  * @deprecated 7.4
+ * @removed 8.0
  */
 function ezmlm_hash ($addr) {}
 
